import React from 'react';
// @ts-ignore
import Image from '@fenderdigital/react-image';
import { AppStoreButtonWidths, AppStoreButtonImageLinks } from './constants';

const clickFactory = (preventDefault = false, stopPropagation = false) => {
  return (event: React.MouseEvent) => {
    if (preventDefault) {
      event.preventDefault();
    }

    if (stopPropagation) {
      event.stopPropagation();
    }
  };
};

interface AppStoreButtonProps {
  preventDefault?: boolean;
  stopPropagation?: boolean;
  variant: 'google' | 'apple';
  imgOverride?: string[];
  link: string;
  className?: string;
  id?: string;
  dataId?: string;
}

const AppStoreButton: React.FC<AppStoreButtonProps> = ({
  variant,
  className = '',
  preventDefault,
  stopPropagation,
  link,
  imgOverride,
  id,
  dataId,
}) => (
  <a
    id={id}
    data-id={dataId}
    href={link}
    target="_blank"
    rel="noopener noreferrer"
    className={`app-store-link outline-0 dib ${className}`}
    style={{ width: AppStoreButtonWidths[variant] }}
    onClick={clickFactory(preventDefault, stopPropagation)}
  >
    <Image
      bgColor="transparent"
      ratio={40 / AppStoreButtonWidths[variant]}
      images={imgOverride || AppStoreButtonImageLinks[variant]}
    />
  </a>
);

export default AppStoreButton;
